@@ -36,6 +36,7 @@ QDltOptManager::QDltOptManager()
     terminate=false;
     convertionmode = e_ASCI;
     commandline_mode = false;
+    delimiter=',';
 }
 
 QDltOptManager* QDltOptManager::getInstance()
@@ -105,11 +106,12 @@ void QDltOptManager::printUsage()
     qDebug()<<" -t or --terminate\tTerminate DLT Viewer after command line execution.";
     qDebug()<<" -v or --version\tOnly show version and buildtime information";
     qDebug()<<" -w workingdirectory\tSet the working directory";
+    qDebug()<<" -delimiter <character>\tThe used delimiter for CSV export (Default: ,).";
     qDebug()<<"\nExamples:";
     qDebug()<<"  dlt-viewer.exe -t -c output.txt input.dlt";
-    qDebug()<<"  dlt-viewer.exe -t -s -u -c output.dlt input.txt";
+    qDebug()<<"  dlt-viewer.exe -t -s -u -c output.txt input.dlt";
     qDebug()<<"  dlt-viewer.exe -t -s -d -c output.dlt input.dlt";
-    qDebug()<<"  dlt-viewer.exe -t -s -p decoded.dlp -dd -c output.dlt input.dlt ";
+    qDebug()<<"  dlt-viewer.exe -t -s decoded.dlp -dd -c output.dlt input.dlt ";
     qDebug()<<"  dlt-viewer.exe -t -s -csv -c output.csv input.dlt";
     qDebug()<<"  dlt-viewer.exe -t -s -d filter.dlf -c output.dlt input.dlt";
     qDebug()<<"  dlt-viewer.exe -p export.dlp -e \"Filetransfer Plugin|export|ftransferdir\" input.dlt";
@@ -190,6 +192,16 @@ void QDltOptManager::parse(QStringList *opt)
 
             i += 1;
          }
+         else if(str.compare("-delimiter")==0)
+         {
+             QString c1 = opt->value(i+1);
+
+             delimiter = QString("%1").arg(c1).front().toLatin1();
+
+             qDebug() << "Delimiter:" << delimiter;
+
+             i += 1;
+         }
         else if(str.compare("-u")==0)
          {
             convertionmode = e_UTF8;
@@ -214,7 +226,6 @@ void QDltOptManager::parse(QStringList *opt)
          {
             QString c = opt->value(i+1);
             postPluginCommands += c;
-            QStringList args = c.split("|");
             commandline_mode = true;
             ++i;
          }
@@ -275,9 +286,16 @@ void QDltOptManager::parse(QStringList *opt)
       * So we have to close it in this case
      */
     #if (WIN32)
-        if ( !commandline_mode)
+        if (!commandline_mode)
         {
-            FreeConsole();
+            HWND consoleWnd = GetConsoleWindow();
+            DWORD dwProcessId;
+            GetWindowThreadProcessId(consoleWnd, &dwProcessId);
+            if (GetCurrentProcessId() == dwProcessId)
+            {
+                // user launched the application with a double click from explorer: we do not need console
+                FreeConsole();
+            }
         }
     #endif
 }
@@ -286,17 +304,8 @@ bool QDltOptManager::isProjectFile(){ return project;}
 bool QDltOptManager::isTerminate(){return terminate;}
 bool QDltOptManager::issilentMode(){return silent_mode;}
 bool QDltOptManager::isCommandlineMode(){return commandline_mode;}
-
-e_convertionmode QDltOptManager::get_convertionmode()
-{
-    return convertionmode;
-}
-
-e_inputmode QDltOptManager::get_inputmode()
-{
-    return inputmode;
-}
-
+e_convertionmode QDltOptManager::get_convertionmode(){return convertionmode;}
+e_inputmode QDltOptManager::get_inputmode(){return inputmode;}
 QString QDltOptManager::getProjectFile(){return projectFile;}
 QStringList QDltOptManager::getLogFiles(){return logFiles;}
 QStringList QDltOptManager::getFilterFiles(){return filterFiles;}
@@ -305,3 +314,4 @@ QString QDltOptManager::getPluginName(){return pluginName;}
 QString QDltOptManager::getCommandName(){return commandName;}
 QStringList QDltOptManager::getCommandParams(){return commandParams;}
 QString QDltOptManager::getWorkingDirectory() const { return workingDirectory; }
+char QDltOptManager::getDelimiter(){return delimiter;}
