@@ -9,6 +9,9 @@ BUILD_DIR="${SRC_DIR}/build"
 INSTALL_DIR="${BUILD_DIR}/install"
 APP_DIR_NAME="DLTViewer"
 
+NPROC=$(nproc)
+echo Nb of cpus: ${NPROC}
+
 rm -rf "${APP_DIR_NAME}"
 rm -rf "${SRC_DIR}/build"
 mkdir -p "${BUILD_DIR}"
@@ -16,7 +19,7 @@ cd "${BUILD_DIR}"
 
 echo Build with QMake
 qmake ../BuildDltViewer.pro
-make
+make -j ${NPROC}
 
 echo Cleanup
 rm -rf "${INSTALL_DIR}"
@@ -37,7 +40,7 @@ cmake -G Ninja \
   -DDLT_RESOURCE_INSTALLATION_PATH="${APP_DIR_NAME}/usr/share" \
   -DDLT_PLUGIN_INSTALLATION_PATH="${APP_DIR_NAME}/usr/bin/plugins" \
   "${SRC_DIR}"
-cmake --build "${BUILD_DIR}" -v
+cmake --build "${BUILD_DIR}" -j ${NPROC} -v
 
 # External CPack generator calls "cmake --install" and "linuxdeploy"
 #
